local kube = import "../../kube/hscloud.libsonnet";
local hspki = import "../../kube/hspki.libsonnet";

{
    local top = self,
    local cfg = self.cfg,

    cfg:: {
        name: 'depotview',
        namespace: 'depotview',
        image: 'registry.k0.hswaw.net/q3k/depotview:1606469687-42b21ecd84b713faf1c65c4ddceb74f559fe94bd',
    },

    local ns = kube.Namespace(cfg.namespace),

    deployment: ns.Contain(kube.Deployment(cfg.name)) {
        spec+: {
            replicas: 1,
            template+: {
                spec+: top.pki.PodSpec {
                    containers_: {
                        default: top.pki.GoContainer("default") {
                            image: cfg.image,
                            executable_: "/devtools/depotview",
                            command+: [
                                "-listen_address", "0.0.0.0:4200",
                            ],
                            resources: {
                                requests: { cpu: "25m", memory: "256Mi" },
                                limits: { cpu: "500m", memory: "512Mi" },
                            },
                            ports_: {
                                grpc: { containerPort: 4200 },
                            },
                        },
                    },
                },
            },
        },
    },

    service: ns.Contain(kube.Service(cfg.name)) {
        target:: top.deployment,
    },

    pki: ns.Contain(hspki) {
        cfg+: {
            name: cfg.name,
        }
    },
}
