import flask
import flask_restful as restful

from io import StringIO
from ._hsldap import HsLdap, hash_from_mifare_id
from pathlib import Path

app = flask.Flask(__name__)
api = restful.Api(app)

app.config['DEBUG'] = True

ldap = HsLdap(password=Path('secrets/ac-ldap-password.txt').read_text().strip())

class Hashes(restful.Resource):
    def get(self, lock):
        if lock not in {'internal', 'external'}:
            flask.abort(404)

        text = StringIO()

        for uid, hashes in ldap.get_hashes(with_neighbours=(lock == 'external')).items():

            for h in hashes['mifareIDHash']:
                text.write(f'{h}\n')

            for h in hashes['mifareID']:
                h = hash_from_mifare_id(h, 0).hex()
                text.write(f'{h}\n')

        text.seek(0)

        return flask.Response(text, mimetype='text/plain')

api.add_resource(Hashes, '/hashes/<lock>')

def __main__():
    app.run(host="localhost", port=8000, debug=False)

if __name__ == '__main__':
    __main__()
