{ pkgs, ... }:

{
  hardware.printers = {
    ensurePrinters = [
      {
        name = "DYMO_LabelWriter450";
        location = "HSWAW";
        # FIXME: roll back to previous serial whenever we switch back to the
        # deep fried printer
        deviceUri = "usb://DYMO/LabelWriter%20450?serial=07080922282341";
        # deviceUri = "usb://DYMO/LabelWriter%20450?serial=14070417114480";
        model = "lw450.ppd";
        ppdOptions = {
          PageSize = "w102h252";
        };
      }

      {
        name = "Zebra_GK420T";
        location = "HSWAW";
        deviceUri = "socket://10.8.1.22:9100";
        model = "drv:///sample.drv/zebra.ppd";
        ppdOptions = {
          PageSize = "w288h432";
          MediaType = "Thermal";
          Resolution = "203dpi";
        };
      }

      {
        name = "Brother_MFC8380DN";
        location = "HSWAW";
        deviceUri = "socket://10.8.1.21";
        model = "BR8380.ppd";
        ppdOptions = {
          PageSize = "A4";
        };
      }
    ];

    ensureDefaultPrinter = "DYMO_LabelWriter450";
  };

    services = {
    avahi = {
      enable = true;
      nssmdns = true;
      openFirewall = true;
      publish = {
        enable = true;
        userServices = true;
      };
    };
    printing = {
      enable = true;
      defaultShared = true;
      browsing = true;
      openFirewall = true;
      allowFrom = [ "all" ];
      listenAddresses = [ "*:631" ];
      drivers = [
        # Workaround for broken multi-copies printing on LW450
        (pkgs.cups-dymo.overrideAttrs (old: {
          postPatch = ''
            sed -i 's/cupsManualCopies: False/cupsManualCopies: True/g' ppd/*
          '';
        }))

        # Official Brother PPD
        (pkgs.runCommand ''cups-brother'' { } ''
          mkdir -p $out/share/cups/model
          gunzip --stdout ${pkgs.fetchurl {
            url = "https://download.brother.com/welcome/dlf006311/BR8380_2_GPL.ppd.gz";
            hash = "sha256-d7Kly2z8ALLV+j2Zmh3knpqiELFS4wf+4MfgNYeC0hQ=";
          }} > $out/share/cups/model/BR8380.ppd
        '')
      ];

      # Requests coming from beyondspace use printmaster.waw.hackerspace.pl:631 host header which Cups doesn't like - let's just allow all
      extraConf = "ServerAlias *";
    };
  };
}