{ pkgs, ... }:
let
  python = pkgs.python3.withPackages (pp: [ pp.paho-mqtt ]);
  src = pkgs.fetchgit {
    url = "https://code.hackerspace.pl/informatic/spejsiot-polycom";
    rev = "b1d41a3473a49ac9ef5771c8e704f33181989d92";
    hash = "sha256-JdjGo1lR9adtHgtZZgtTf9uOhMzc/3OvO2/r6R/QipE=";
  };
in {
  # Expose serial USB-Serial adapter connected to Polycom EF2280 mixer on TCP
  # port 10001
  systemd.services.socat-polycom = {
    description = "Expose USB-serial adapter for Polycom EF2280 over TCP 10001";
    wantedBy = [ "multi-user.target" ];
    after = [ "network.target" ];

    serviceConfig = {
      ExecStart = "${pkgs.socat}/bin/socat TCP4-LISTEN:10001,fork,reuseaddr /dev/serial/by-id/usb-1a86_USB2.0-Ser_-if00-port0,b38400,nonblock,raw,echo=0";
      DynamicUser = true;
      SupplementaryGroups = "dialout";
      Restart = "always";
    };
  };

  systemd.services.spejsiot-polycom = {
    description = "Polycom EF2280 MQTT control bridge";
    wantedBy = [ "multi-user.target" ];
    after = [ "network.target" ];

    serviceConfig = {
      ExecStart = "${python}/bin/python3 ${src}/vortexiot.py";
      DynamicUser = true;
      Restart = "always";
    };

    environment.CONFIG_PATH = pkgs.writeText "config.json" (builtins.toJSON {
      mqtt = { host = "127.0.0.1"; };
      control = { host = "127.0.0.1";  port = 10001; };
      inputs = {
        aux1 = [ "1" "2" ];
        sound = [ "A" "B" ];
        hdmi = [ "C" "D" ];
      };
      outputs = {
        main = [ "1" "2" ];
      };
    });
  };

  networking.firewall.allowedTCPPorts = [ 10001 ];
}
